# Code of Conduct

👋 Welcome to InftyAI community !

- [Scope](#scope)
- [Our Standards](#our-standards)

## Scope

This code of conduct applies within project and community spaces.

## Our Standards

Examples of behavior that contributes to a positive environment include but are not limited to:

- Demonstrating empathy and kindness toward other people
- Being respectful of differing opinions, viewpoints, and experiences
- Giving and gracefully accepting constructive feedback
- Accepting responsibility and apologizing to those affected by our mistakes,
  and learning from the experience
- Focusing on what is best not just for us as individuals, but for the
  overall community
- Using welcoming and inclusive language

Examples of unacceptable behavior include but are not limited to:

- The use of sexualized language or imagery
- Trolling, insulting or derogatory comments, and personal or political attacks
- Public or private harassment in any form
- Publishing others' private information, such as a physical or email
  address, without their explicit permission
- Violence, threatening violence, or encouraging others to engage in violent behavior
- Stalking or following someone without their consent
- Unwelcome physical contact
- Unwelcome sexual or romantic attention or advances
- Other conduct which could reasonably be considered inappropriate in a
  professional setting

The following behaviors are also prohibited:

- Providing knowingly false or misleading information in connection with a Code of Conduct investigation or otherwise intentionally tampering with an investigation.
- Retaliating against a person because they reported an incident or provided information about an incident as a witness.
